import os
import pytest
from tempath import autodir, autofile


@pytest.fixture
def ten():
    return 10

def test_ten(ten):
    assert ten > 5

def test_autodir():
    fd = autodir()
    assert os.path.exists(fd)

def test_autofile_filecount():
    fd = autodir(folders=0, files=2)
    size = len(os.listdir(fd))
    assert size == 2

def test_ten(ten):
    assert ten > 5

def test_autofile():
    fd = autofile()
    assert os.path.exists(fd)

def test_autofile_size_10():
    kb = 1 << 10
    fd = autofile(size=kb)
    size = os.path.getsize(fd)
    assert size == kb

def test_autofile_size_16():
    kb = 1 << 16
    fd = autofile(size=kb)
    size = os.path.getsize(fd)
    assert size == kb

def test_autofile_size_1M():
    kb = 1 << 20
    fd = autofile(size=kb)
    size = os.path.getsize(fd)
    assert size == kb



import os
import shutil
import atexit
import random
import string

class TempFileError(Exception):
    def __init__(cls, *args, **kwargs):
        super().__init__(*args, **kwargs)

class Register:

    def __init__(self):
        self.paths = []
        if not os.path.exists("TempFolder"):
            os.mkdir("TempFolder")
        self.path = os.path.abspath("TempFolder")

    def include(self, path):
        if not os.path.exists(path):
            os.mkdir(path)
        self.paths.append(path)

    def clean(self):
        rmpath(self.path)

Reg = Register()


def rmpath(path):
    if os.path.exists(path):
        if os.path.isfile(path):
            os.remove(path)
        elif os.path.isdir(path):
            shutil.rmtree(path)
        else:
            raise TempFileError(f"Cannot interperet {path}.")

def _randline(length=63):
    choices = string.printable + string.whitespace
    line = "".join([random.choice(choices) for _ in range(length)]) + "\n"
    return line.encode("utf-8")

def _getline(length=63):
    phrase = "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum."
    return phrase[:length].encode("utf-8")

def fillfile(path, size=16384, random=False):
    total = 0
    if random:
        line = _randline()
    else:
        line = _getline()
    linelen = len(line)
    with open(path, "wb") as fd:
        while total + linelen < size:
            fd.write(line)
            total += linelen
        fd.write(line[:size-total])
    return fd

def autofile(size=16384, random=False):
    tempfile = os.path.join(Reg.path,"testfile.tmp")
    fillfile(tempfile, size=size, random=random)
    Reg.include(tempfile)
    return tempfile

def filldir(path, count=1, size=16384, random=False):
    Reg.include(path)
    for i in range(count):
        name = f"testfile_{i}.tmp"
        full = os.path.join(path, name)
        fillfile(full, size=size, random=random)
    return

def autodir(folders=0,files=2,size=16384,random=False):
    tempdir = os.path.join(Reg.path, "test_folder")
    Reg.include(tempdir)
    for i in range(folders):
        testdir = os.path.join(tempdir, f"testdir{i}")
        filldir(testdir, count=files, size=size, random=random)
    filldir(tempdir, count=files, size=size, random=random)
    return tempdir

@atexit.register
def cleanup():
    list(map(rmpath, Reg.paths))
    Reg.clean()



#! /usr/bin/python3
# -*- coding: utf-8 -*-

#############################################################################
# Copyright (C) 2021 alexpdev
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
############################################################################

from setuptools import setup, find_packages
import json

INFO = json.load(open('./package.json'))

def readme():
    with open("README.md", encoding="UTF-8") as fd:
        long_description = fd.read()
    return long_description

setup(
    name=INFO['name'],
    version=INFO['version'],
    description=INFO['description'],
    long_description=readme(),
    long_description_content_type="text/markdown",
    classifiers=[
        "Programming Language :: Python :: 3.0",
        "Programming Language :: Python :: 3.1",
        "Programming Language :: Python :: 3.2",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Development Status :: 3 - Alpha",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: GNU Lesser General Public License v3 or later (LGPLv3+)",
    ],
    keywords=INFO["keywords"],
    author=INFO["author"],
    author_email=INFO["email"],
    url=INFO["url"],
    project_urls={"Source Code": "https://github.com/alexpdev/tempath"},
    license=INFO["license"],
    packages=find_packages(exclude=["env","tests"]),
    include_package_data=True,
    tests_require=['pytest'],
    setup_requires=["setuptools", 'wheel'],
    zip_safe=False,
    test_suite='complete',
)
